dj_anonymizer [![Build Status](https://github.com/preply/dj_anonymizer/actions/workflows/test.yml/badge.svg)](https://travis-ci.com/preply/dj_anonymizer) [![codecov.io](https://codecov.io/github/preply/dj_anonymizer/coverage.svg?branch=master)](https://codecov.io/github/preply/dj_anonymizer?branch=master) [![PyPI version](https://badge.fury.io/py/dj-anonymizer.svg)](https://badge.fury.io/py/dj_anonymizer)
==================================

dj_anonymizer helps anonymize production database with any kind of fake data.

Project works with Django 2.2 or higher and Python 3.5 or higher.

Documentation
==================================
[https://dj-anonymizer.readthedocs.io/en/latest/](https://dj-anonymizer.readthedocs.io/en/latest/)
